.. _citation:

=================
Citing *BIDSonym*
=================

If you are using ``BIDSonym`` in your work, please consider citing the 
`GitHub repository <https://github.com/PeerHerholz/BIDSonym>`_ 
until we have a formal publication out there.